#!/bin/bash
#
#   NOTE:  we build libxml2 with the native compiler

usage()
{
   echo "USAGE: `basename ${0}` <product_directory> <debug|opt|prof> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
    if [ -z ${SSIBUILDSHIMS_DIR} ]
    then
       echo "ERROR: failed to setup ssibuildshims ${ssibuildshims_version}"
       exit 1
    fi
}

# -------------------------------------------------------------------
# start processing

product_dir=${1}
extraqual=${2}
maketar=${3}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=libxml2
origpkgver=v2_9_9-rc2
pkgver=${origpkgver//-/_}
ssibuildshims_version=v1_04_12
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarname=${package}-${pkgdotver}
pkgtardir=${package}-${pkgdotver%-rc*}

get_this_dir
get_ssibuildshims
source define_basics NO_BASE_QUAL

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
    exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

if [ "${extraqual}" = "debug" ]
then
    cxxflg="-g -O0"
elif [ "${extraqual}" = "opt" ]
then
    cxxflg="-O3 -g -DNDEBUG"
elif [ "${extraqual}" = "prof" ]
then
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
fi

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi
mkdir -p ${sourcedir}
if [ ! -d ${sourcedir} ]
then
   echo "ERROR: failed to create ${sourcedir}"
   exit 1
fi

ncore=`${SSIBUILDSHIMS_DIR}/bin/ncores`

set -x

cd ${sourcedir}
tar xf ${tardir}/${pkgtarname}.tar.gz

export LIBXML2_SOURCE=${sourcedir}/${pkgtardir}

cd "${LIBXML2_SOURCE}"

for patch in ${patchdir}/*.patch; do
  if grep -e '^\(---\|+++\) [ab]/' ${patch} >/dev/null 2>&1; then
    pval=1
  else
    pval=0
  fi
  patch ${DEBUG_PATCHES:+--verbose} -p${pval} < "${patch}" || ssi_die "application of patch ${patch} failed."
done

cd ${blddir}
CFLAGS="${cxxflg}" ${LIBXML2_SOURCE}/configure --prefix=${pkgdir} --without-python || ssi_die "configure failed."
make -j ${ncore} || ssi_die "make failed."
# 2.9.4 still has failing test on OS X.
[[ "${OSTYPE}" == darwin* ]] || make -j ${ncore} check || ssi_die "make check failed."
make -j ${ncore} install || ssi_die "make install failed."

set +x

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# real ups declare
${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} ${fullqual}

# -------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -q ${fullqual} -z ${product_dir}
echo "${package} headers are installed in ${LIBXML2_INC}"

# fixing embedded path
mv ${LIBXML2_FQ_DIR}/bin/xml2-config ${LIBXML2_FQ_DIR}/bin/xml2-config.bak
cat ${LIBXML2_FQ_DIR}/bin/xml2-config.bak | sed 's%^prefix=.*$%prefix=${LIBXML2_FQ_DIR}%' > ${LIBXML2_FQ_DIR}/bin/xml2-config
mv ${LIBXML2_FQ_DIR}/lib/xml2Conf.sh ${LIBXML2_FQ_DIR}/lib/xml2Conf.sh.bak
cat ${LIBXML2_FQ_DIR}/lib/xml2Conf.sh.bak | \
   sed 's%^XML2_LIBDIR=.*$%XML2_LIBDIR="-L${LIBXML2_FQ_DIR}/lib"%' | \
   sed 's%^XML2_INCLUDEDIR=.*$%XML2_INCLUDEDIR="-I${LIBXML2_FQ_DIR}/include/libxml2"%' \
   > ${LIBXML2_FQ_DIR}/lib/xml2Conf.sh
chmod +x ${LIBXML2_FQ_DIR}/bin/xml2-config

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
    ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} ${fullqual}
fi

exit 0
